from functools import partial

from resources.lib.const import SETTINGS, LANG_CODE
from resources.lib.kodilogging import logger
from resources.lib.storage.storage import storage
from resources.lib.utils.kodiutils import get_settings, show_settings, set_settings, get_setting_as_bool, \
    get_setting_as_int


class Settings:
    def __init__(self):
        self._select = {
            SETTINGS.PREFERRED_LANGUAGE: [LANG_CODE.CS, LANG_CODE.SK, LANG_CODE.EN],
            SETTINGS.FALLBACK_LANGUAGE: [None, LANG_CODE.CS, LANG_CODE.SK, LANG_CODE.EN],
            SETTINGS.SUBTITLES_PROVIDER_PREFERRED_LANGUAGE: [LANG_CODE.CS, LANG_CODE.SK, LANG_CODE.EN],
            SETTINGS.SUBTITLES_PROVIDER_FALLBACK_LANGUAGE: [None, LANG_CODE.CS, LANG_CODE.SK, LANG_CODE.EN],
        }

    def __setitem__(self, key, value):
        self._set(key, value)

    def __getitem__(self, key):
        return self._get(key)

    @staticmethod
    def _get(key):
        return get_settings(key)

    @staticmethod
    def _set(key, value):
        set_settings(key, value)

    @staticmethod
    def as_bool(key):
        return get_setting_as_bool(key)

    @staticmethod
    def as_int(key):
        return get_setting_as_int(key)

    @staticmethod
    def show():
        show_settings()

    @staticmethod
    def dynamic(key):
        return partial(get_settings, key)

    def get_select(self, key):
        return self._select.get(key)[int(self[key])]

    def set_select(self, key, value):
        return self._set(key, self._select[key].index(value))

    def get_languages(self, *args):
        languages = []
        for lang in args:
            select_lang = self.get_select(lang)
            if select_lang:
                languages.append(select_lang)
        return languages


settings = Settings()
